aboutsummaryrefslogtreecommitdiffstats
path: root/host/tests
diff options
context:
space:
mode:
Diffstat (limited to 'host/tests')
-rw-r--r--host/tests/error_test.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/host/tests/error_test.cpp b/host/tests/error_test.cpp
index 3499c25da..983f0150c 100644
--- a/host/tests/error_test.cpp
+++ b/host/tests/error_test.cpp
@@ -37,9 +37,9 @@ BOOST_AUTO_TEST_CASE(test_assert_has){
vec.push_back(3);
vec.push_back(5);
- //verify the std::has utility
- BOOST_CHECK(std::has(vec, 2));
- BOOST_CHECK(not std::has(vec, 1));
+ //verify the uhd::has utility
+ BOOST_CHECK(uhd::has(vec, 2));
+ BOOST_CHECK(not uhd::has(vec, 1));
std::cout << "The output of the assert_has error:" << std::endl;
try{